@@ -1,13 +1,11 @@
 package Util::Underscore;
 
 #ABSTRACT: Common helper functions without having to import them
-#CONTRIBUTOR: Lukas Atkinson (cpan: AMON) <amon@cpan.org>
-#CONTRIBUTOR: Olivier Mengué (cpan: DOLMEN) <dolmen@cpan.org>
 
 use strict;
 use warnings;
 
-use version 0.77; our $VERSION = qv('v1.2.1');
+use version 0.77; our $VERSION = qv('v1.3.0');
 use overload ();
 
 use Carp ();
@@ -19,6 +17,7 @@ use List::Util 1.35      ();
 use POSIX ();
 use Scalar::Util 1.36 ();
 use Try::Tiny 0.03    ();
+use IPC::Run 0.92 ();
 
 
 BEGIN {
@@ -149,6 +148,7 @@ sub File(@) {    ## no critic (NamingConventions::Capitalization)
     Path::Class::File->new(@_);
 }
 
+
 $_ASSIGN_ALIASES->(
     'Data::Dump',
     pp => 'pp',
@@ -156,6 +156,30 @@ $_ASSIGN_ALIASES->(
 );
 
 
+## no critic (ProhibitBuiltinHomonyms)
+sub caller(;$) {
+    require Util::Underscore::CallStackFrame;
+    Util::Underscore::CallStackFrame->of(@_ ? shift() + 1 : 1);
+}
+
+sub callstack(;$) {
+    my $level = @_ ? shift() + 1 : 1;
+    my @callers;
+    while (my $caller = Util::Underscore::CallStackFrame->of($level + @callers))
+    {
+        push @callers, $caller;
+    }
+    return @callers;
+}
+
+
+$_ASSIGN_ALIASES->(
+    'IPC::Run',
+    process_run     => 'run',
+    process_start   => 'start',
+);
+
+
 
 1;
 
@@ -171,7 +195,7 @@ Util::Underscore - Common helper functions without having to import them
 
 =head1 VERSION
 
-version v1.2.1
+version v1.3.0
 
 =head1 SYNOPSIS
 
@@ -218,7 +242,9 @@ C<is_string>,
 C<is_bool>,
 C<is_tainted>,
 C<is_vstring>,
-C<new_dual>
+C<new_dual>,
+C<chomp>,
+C<index>
 
 =item Numbers
 
@@ -283,6 +309,15 @@ C<sum>,
 C<uniq>,
 C<zip>
 
+see L<Util::Underscore::ListUtilsBy|Util::Underscore::ListUtilsBy>
+
+C<max_by>,
+C<max_str_by>,
+C<min_by>,
+C<min_str_by>,
+C<uniq_by>,
+C<classify>
+
 =item Exception handling
 
 see below
@@ -303,11 +338,15 @@ C<try>
 
 see below
 
+C<caller>,
+C<callstack>,
 C<dd>,
 C<Dir>,
 C<File>,
 C<is_open>,
 C<pp>,
+C<process_run>,
+C<process_start>,
 C<prototype>
 
 =back
@@ -392,6 +431,86 @@ wrapper for C<Data::Dump::dd>.
 
 =back
 
+This module also includes an object-oriented interface to the callstack.
+See L<Util::Underscore::CallStackFrame|Util::Underscore::CallStackFrame> for further details.
+
+=over 4
+
+=item C<@stack_frames = _::callstack>
+
+=item C<@stack_frames = _::callstack $start_from_level>
+
+Assembles a list of call stack frames.
+
+B<$start_from_level>:
+The level starting from which frames should be constructed.
+For example, C<1> would start from the immediate caller, whereas C<0> includes the current frame as well.
+If ommited, uses C<1>.
+
+B<returns>:
+A list of C<Util::Underscore::CallStackFrame> objects.
+
+=C<$stack_frame = _::caller>
+=C<$stack_frame = _::caller $level>
+
+Assembles an object representing a specific call stack frame.
+
+B<$level>:
+The level of which the call stack frame is to be returned.
+A value of C<1> would return the immediate caller, whereas C<0> would indicate the current frame.
+If ommited, uses C<1>.
+
+B<returns>:
+A C<Util::Underscore::CallStackFrame> instance representing the requested stack frame.
+If no such frame exists, C<undef> is returned.
+
+=back
+
+For invoking external commands, Perl offers the C<sytem> command, various modes for C<open>, and the backtick operator (C<qx//>).
+However, these modes encourage interpolating variables directly into a string, which opens up shell injection issues.
+In fact, C<open> and C<system> can't avoid shell injection when piping or redirection is involved.
+The L<IPC::Run|IPC::Run> module avoids this by offering a flexible interface for launching and controlling external processes.
+
+=over 4
+
+=item C<$success = _::process_run COMMAND_SPEC>
+
+Spawns the specified command(s), and blocks until completion.
+
+B<COMMAND_SPEC>:
+An IPC::Run harness specification.
+
+B<returns>:
+A boolean indicating whether all spawned processes completed without errors (all sub-processes have exit code zero).
+This is inverse to Perl's built in C<system> function!
+
+Example:
+
+    my $data = "stuff you want to display with a pager.";
+    
+    # The contents of $data are entered via STDIN
+    _::process_run ['less', '-R'], \$data
+        or die "Couldn't run less: $?";
+
+    # To do that same thing using builtin functions, we'd have to do:
+    my $less_pid = open my $less_fh, '|-', 'less', '-R' or die "Couldn't start less: $!";
+    print $less_fh $data;
+    close $less_fh or die "Couldn't close pipe to less: $!";
+    waitpid $less_pid, 0;
+
+=item C<$process = _::process_start COMMAND_SPEC>
+
+Spawns the specified command(s).
+
+B<COMMAND_SPEC>:
+An IPC::Run harness specification.
+
+B<returns>:
+A IPC::Run object that represents the launched process(es).
+To await completion, call C<< $process->finish >>.
+
+=back
+
 =head1 RATIONALE
 
 =head4 Context and Package Name
@@ -441,7 +560,7 @@ L<Safe::Isa|Safe::Isa>.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/latk/Underscore/issues
+https://github.com/latk/p5-Util-Underscore/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -449,28 +568,19 @@ feature.
 
 =head1 AUTHOR
 
-Lukas Atkinson <amon@cpan.org>
-
-=head2 CONTRIBUTORS
-
-=over 4
-
-=item *
-
 Lukas Atkinson (cpan: AMON) <amon@cpan.org>
 
-=item *
+=head2 CONTRIBUTOR
 
-Olivier MenguÃ© (cpan: DOLMEN) <dolmen@cpan.org>
+=for stopwords Olivier Mengué (cpan: DOLMEN)
 
-=back
+Olivier Mengué (cpan: DOLMEN) <dolmen@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Lukas Atkinson.
+This software is copyright (c) 2014 by Lukas Atkinson.
 
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
