@@ -1,8 +1,6 @@
 package Util::Underscore::Numbers;
 
 #ABSTRACT: Functions for dealing with numbers
-#CONTRIBUTOR: Lukas Atkinson (cpan: AMON) <amon@cpan.org>
-#CONTRIBUTOR: Olivier Mengué (cpan: DOLMEN) <dolmen@cpan.org>
 
 use strict;
 use warnings;
@@ -54,7 +52,7 @@ Util::Underscore::Numbers - Functions for dealing with numbers
 
 =head1 VERSION
 
-version v1.2.1
+version v1.3.0
 
 =head1 FUNCTION REFERENCE
 
@@ -141,7 +139,7 @@ If the C<$float> is not a finite number (i.e. infinite or NaN), then that input
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/latk/Underscore/issues
+https://github.com/latk/p5-Util-Underscore/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -149,14 +147,13 @@ feature.
 
 =head1 AUTHOR
 
-Lukas Atkinson <amon@cpan.org>
+Lukas Atkinson (cpan: AMON) <amon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Lukas Atkinson.
+This software is copyright (c) 2014 by Lukas Atkinson.
 
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
