@@ -1,8 +1,6 @@
 package Util::Underscore::Scalars;
 
 #ABSTRACT: Functions for introspecting and manipulating scalars
-#CONTRIBUTOR: Lukas Atkinson (cpan: AMON) <amon@cpan.org>
-#CONTRIBUTOR: Olivier Mengué (cpan: DOLMEN) <dolmen@cpan.org>
 
 use strict;
 use warnings;
@@ -65,6 +63,50 @@ sub is_package(_) {
         && scalar($_[0] =~ /\A [^\W\d]\w* (?: [:][:]\w+ )* \z/xsm);
 }
 
+sub chomp(_;$) {
+
+    # localizedly set the input record separator
+    local $/ = $/;
+    if (@_ > 1) {
+        if (_::is_string $_[1]) {
+            $/ = "$_[1]";
+        }
+        else {
+            Carp::croak q(_::chomp: second argument must be a string);
+        }
+    }
+
+    # handle a single string
+    # ATTENTION: this depends on _::is_string
+    if (_::is_string $_[0]) {
+        CORE::chomp(my $copy = $_[0]);
+        return $copy;
+    }
+
+    # handle an arrayref of strings (effectively auto-mapping)
+    # ATTENTION: _::is_array_ref will be defined later
+    elsif (_::is_array_ref($_[0])) {
+        my @result = @{ $_[0] };
+        for (@result) {
+            goto ERROR if not _::is_string;
+            CORE::chomp;
+        }
+        return \@result;
+    }
+
+    ERROR:
+    Carp::croak
+        q(_::chomp: first argument must be string or arrayref of strings);
+}
+
+sub index($$;$) {
+    if (@_ >= 3 and $_[2] < 0) {
+        Carp::croak q(_::index: starting position must be non-negative.)
+    }
+    my $result = CORE::index($_[0], $_[1], $_[2] // 0);
+    return ($result >= 0) ? $result : undef;
+}
+
 1;
 
 __END__
@@ -79,7 +121,7 @@ Util::Underscore::Scalars - Functions for introspecting and manipulating scalars
 
 =head1 VERSION
 
-version v1.2.1
+version v1.3.0
 
 =head1 FUNCTION REFERENCE
 
@@ -287,7 +329,7 @@ a boolean indicating whether the given C<$scalar> can be considered to be a bool
 
 =item C<$bool = _::is_identifier $string>
 
-=item C<$bool = _::is_identifier $>
+=item C<$bool = _::is_identifier>
 
 Checks that the given string would be a legal identifier:
 a letter followed by zero or more word characters.
@@ -312,12 +354,68 @@ a string possibly containing a package name.
 B<returns>:
 a boolean indicating whether the given string looks like a package name.
 
+=item C<$str = _::chomp>
+
+=item C<$str = _::chomp $line>
+
+=item C<$str = _::chomp $line, $end>
+
+=item C<$str_array = _::chomp \@lines>
+
+=item C<$str_array = _::chomp \@lines, $end>
+
+Performs the C<chomp> builtin on a I<copy> of the input – this will not modify the input.
+
+B<$line>, B<\@lines>:
+a string or a reference to an array of strings.
+These will not be modified.
+If omitted, uses C<$_>.
+
+B<$end>:
+a string designating the I<input record separator>.
+If not specified, uses C<$/>.
+
+B<returns>:
+If given a single C<$line>, returns a copy of that string with the C<end> removed.
+If given multiple C<\@lines>, returns an array reference containing copies of the input lines, with the C<$end> removed from each copy.
+
+Examples:
+
+    # assuming the default $/ = "\n":
+    _::chomp ["foo\n", "bar", "baz\n"];
+    #=> ["foo", "bar", "baz"]
+    
+    # removing a custom terminator:
+    _::chomp "foobar", "bar";
+    #=> "foo"
+
+=item C<$pos = _::index $haystack, $needle>
+
+=item C<$pos = _::index $haystack, $needle, $start>
+
+Wraps the builtin C<index> function to return C<undef> rather than C<-1> if the C<$needle> wasn't found in the C<$haystack>.
+
+B<$haystack>:
+a string in which to search.
+
+B<$needle>:
+a string for which to search.
+
+B<$start>:
+the position at which to start searching.
+This must be a non-negative integer.
+Defaults to zero.
+
+B<returns>:
+The position at which the C<$needle> was found in the C<$haystack>,
+If no match was found, returns C<undef>.
+
 =back
 
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/latk/Underscore/issues
+https://github.com/latk/p5-Util-Underscore/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -325,14 +423,13 @@ feature.
 
 =head1 AUTHOR
 
-Lukas Atkinson <amon@cpan.org>
+Lukas Atkinson (cpan: AMON) <amon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Lukas Atkinson.
+This software is copyright (c) 2014 by Lukas Atkinson.
 
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
