@@ -51,7 +51,7 @@ _.pm - do not use this module directly
 
 =head1 VERSION
 
-version v1.2.1
+version v1.3.0
 
 =head1 DESCRIPTION
 
@@ -66,7 +66,7 @@ The functions in the C<_> namespace are documented in the L<Util::Underscore|Uti
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/latk/Underscore/issues
+https://github.com/latk/p5-Util-Underscore/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -74,14 +74,13 @@ feature.
 
 =head1 AUTHOR
 
-Lukas Atkinson <amon@cpan.org>
+Lukas Atkinson (cpan: AMON) <amon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Lukas Atkinson.
+This software is copyright (c) 2014 by Lukas Atkinson.
 
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
